Scality Object Storage backend for OpenStack Swift
==================================================
This package implements a back-end for OpenStack_ Swift_ storing objects in a
Scality_ RING installation.

.. _OpenStack: http://openstack.org
.. _Swift: http://docs.openstack.org/developer/swift/
.. _Scality: http://scality.com

Installation
------------
See the documentation_.

.. _documentation: doc/installation.rst
